(* ::Package:: *)

(* ::Input::Initialization:: *)
(*Accessory parameters and properties of the re-entrant jet cavity flow*)
(* over an oblique flat plate *)
(* Author: Dmitri Maklakov, Kazan Federal University, January 2021 *)
(* Do not forget that in "usage" the mathematical formulae of the type Subscript[C, N] are impossible.*)  



(* ::Input::Initialization:: *)
BeginPackage[ "ReentrantJet`"]


(* ::Input::Initialization:: *)
fnum::usage="\!\(\*
StyleBox[\"fnum: Computation\",\nFontSize->16,\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",\nFontSize->16,\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"of\",\nFontSize->16,\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",\nFontSize->16,\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"the\",\nFontSize->16,\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",\nFontSize->16,\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"accessory\",\nFontSize->16,\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",\nFontSize->16,\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"parameters\",\nFontSize->16,\nFontWeight->\"Bold\"]\) 
\!\(\*
StyleBox[\"Usage\",\nFontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\":\",\nFontColor->RGBColor[1, 0, 0]]\) fnum[\[Alpha],\[Beta],\[Sigma]], where \[Alpha] is the angle of attack, \[Beta] is the  inclination angle of the re-entran jet, \[Sigma] is the cavitation number.
Reliable  ranges of \[Alpha], \[Beta] and \[Sigma] at which the author garanties the convergence of the algorithm:  
0<\[Alpha]<= \[Pi]/2,    \[Pi]/2<= \[Beta]<= 3\[Pi]/2,    0<\[Sigma]<= 8. 
\!\(\*
StyleBox[\"Output\",\nFontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\":\",\nFontColor->RGBColor[1, 0, 0]]\) The list  of 7 elements: {a, b, c, d, k, err, iappr}, 
where err is the maximum modulus of the right-hand sides of the system of equations for finding the accessory parameters.,
iappr is the number of attempts to calculate the accesssory parameters in the competion of three initial approximations."


(* ::Input::Initialization:: *)
param::usage="\!\(\*
StyleBox[\" param: Hydrodynamic\",\nFontSize->16,\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",\nFontSize->16,\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"properties\",\nFontSize->16,\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",\nFontSize->16]\)
\!\(\*
StyleBox[\"Usage\",\nFontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\":\",\nFontColor->RGBColor[1, 0, 0]]\) param[\[Alpha],\[Beta],\[Sigma]], where \[Alpha] is the angle of attack, \[Beta] is the inclination angle of the re-entran jet, \[Sigma] is the cavitation number.
Ranges of \[Alpha], \[Beta] and \[Sigma]:   
0<\[Alpha]<= \[Pi]/2,    \[Pi]/2<= \[Beta]<= 3\[Pi]/2,    0<\[Sigma]<= 8. 
\!\(\*
StyleBox[\"Output\",\nFontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\":\",\nFontColor->RGBColor[1, 0, 0]]\) The nested  list  of 4 elements. Each element is a group of several hydrodanamic parmeters. 
\!\(\*
StyleBox[\"Group\",\nFontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",\nFontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"1.\",\nFontColor->RGBColor[1, 0, 0]]\) \!\(\*
StyleBox[\"Mathematical\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\" \",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\"parameters\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\":\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0, 0, 1]]\) {a,b,c,d,k,J,err},  where J=l/l\!\(\*
StyleBox[\"0\",\nFontSize->8,\nFontWeight->\"Bold\"]\), err is the maximum modulus of the right-hand sides of the system of equations for finding the accessory parameters.
\!\(\*
StyleBox[\"Group\",\nFontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",\nFontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"2.\",\nFontColor->RGBColor[1, 0, 0]]\) \!\(\*
StyleBox[\"Hydrodanamic\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\" \",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\"coefficients\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\":\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0, 0, 1]]\) {C\!\(\*
StyleBox[\"N\",\nFontSize->8,\nFontWeight->\"Bold\"]\),C\!\(\*
StyleBox[\"M\",\nFontSize->8,\nFontWeight->\"Bold\"]\), C\!\(\*
StyleBox[\"\[CapitalGamma]\",\nFontSize->8,\nFontWeight->\"Bold\"]\)}, where
C\!\(\*
StyleBox[\"N\",\nFontSize->8,\nFontWeight->\"Bold\"]\)=2N/(\[Rho]V\!\(\*
StyleBox[\"\[Infinity]\",\nFontSize->8,\nFontWeight->\"Bold\"]\)^2 l) is the normal force coefficient, 
C\!\(\*
StyleBox[\"M\",\nFontSize->8,\nFontWeight->\"Bold\"]\)=2M/(\[Rho]V\!\(\*
StyleBox[\"\[Infinity]\",\nFontSize->8,\nFontWeight->\"Bold\"]\)^2 l^2) is the moment coefficient, 
C\!\(\*
StyleBox[\"\[CapitalGamma]\",\nFontSize->8,\nFontWeight->\"Bold\"]\)=\[CapitalGamma]/(lV\!\(\*
StyleBox[\"\[Infinity]\",\nFontSize->8,\nFontWeight->\"Bold\"]\)) is the coefficient of circulation,
l is the length of the plate,
V\!\(\*
StyleBox[\"\[Infinity]\",\nFontSize->9]\) is the incident velocity.  
\!\(\*
StyleBox[\"Group\",\nFontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",\nFontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"3.\",\nFontColor->RGBColor[1, 0, 0]]\) \!\(\*
StyleBox[\"Geometric\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\" \",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\"characteristic\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\":\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0, 0, 1]]\) {\[Delta]/l, Lc/l, Hc/l, Xrect/l, Yrect/l, h/l}, where 
\[Delta]/l  is the dimensionless width of the re-entrant jet, 
Lc/l is the dimensionless length of the cavity,
Hc/l is the dimensionless width of the cavity,
Xrect/l is the dimensionless abscissa of the upper left corner of the rectangle in which the body-cavity is inscribed,  
Yrect/l is the dimensionless ordinate of the upper left corner of the rectangle in which the body-cavity is inscribed, 
h/l is the dimensionless lever of the average  algebraic momentum of the remote part of the re-entrant jet. 
\!\(\*
StyleBox[\"Group\",\nFontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\" \",\nFontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\"4.\",\nFontColor->RGBColor[1, 0, 0]]\) \!\(\*
StyleBox[\"Conformal\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\" \",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\"mapping\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\":\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0, 0, 1]]\) {z(u)/l, z(1/u)/l}, where
z[u]/l is the dimensionless conformal mapping in the form of a pure function. Usage: z[u_]=param[\[Alpha],\[Beta],\[Sigma]][[4,1]][u], 
z[1/u]/l is the conformal mapping of the lower left quadrant onto the flow region. Usage: z1[u_]=param[\[Alpha],\[Beta],\[Sigma]][[4,2]][u]."


(* ::Input::Initialization:: *)
paramlim::usage="\!\(\*
StyleBox[\"paramlim: Computation\",\nFontSize->16,\nFontWeight->\"Bold\",\nFontColor->GrayLevel[0]]\)\!\(\*
StyleBox[\" \",\nFontSize->16,\nFontWeight->\"Bold\",\nFontColor->GrayLevel[0]]\)\!\(\*
StyleBox[\"of\",\nFontSize->16,\nFontWeight->\"Bold\",\nFontColor->GrayLevel[0]]\)\!\(\*
StyleBox[\" \",\nFontSize->16,\nFontWeight->\"Bold\",\nFontColor->GrayLevel[0]]\)\!\(\*
StyleBox[\"the\",\nFontSize->16,\nFontWeight->\"Bold\",\nFontColor->GrayLevel[0]]\)\!\(\*
StyleBox[\" \",\nFontSize->16,\nFontWeight->\"Bold\",\nFontColor->GrayLevel[0]]\)\!\(\*
StyleBox[\"limiting\",\nFontSize->16,\nFontWeight->\"Bold\",\nFontColor->GrayLevel[0]]\)\!\(\*
StyleBox[\" \",\nFontSize->16,\nFontWeight->\"Bold\",\nFontColor->GrayLevel[0]]\)\!\(\*
StyleBox[\"flow\",\nFontSize->16,\nFontWeight->\"Bold\",\nFontColor->GrayLevel[0]]\)\!\(\*
StyleBox[\" \",\nFontSize->16,\nFontWeight->\"Bold\",\nFontColor->GrayLevel[0]]\)\!\(\*
StyleBox[\"configuration\",\nFontSize->16,\nFontWeight->\"Bold\",\nFontColor->GrayLevel[0]]\)\!\(\*
StyleBox[\" \",\nFontSize->16,\nFontWeight->\"Bold\",\nFontColor->GrayLevel[0]]\)\!\(\*
StyleBox[\"at\",\nFontSize->16,\nFontWeight->\"Bold\",\nFontColor->GrayLevel[0]]\)\!\(\*
StyleBox[\" \",\nFontSize->16,\nFontWeight->\"Bold\",\nFontColor->GrayLevel[0]]\)\!\(\*
StyleBox[\"\[Alpha]\",\nFontSize->16,\nFontWeight->\"Bold\",\nFontColor->GrayLevel[0]]\)\!\(\*
StyleBox[\"=\",\nFontSize->16,\nFontWeight->\"Bold\",\nFontColor->GrayLevel[0]]\)\!\(\*
StyleBox[\"0\",\nFontSize->16,\nFontWeight->\"Bold\",\nFontColor->GrayLevel[0]]\)\[IndentingNewLine]\!\(\*
StyleBox[\"Usage\",\nFontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\":\",\nFontColor->RGBColor[1, 0, 0]]\)  paramlim[\[Sigma]], where \[Sigma]\[Element][0,8] is the cavitation number
   \!\(\*
StyleBox[\"   Output\",\nFontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\":\",\nFontColor->RGBColor[1, 0, 0]]\) The list of four elements (see section 5):
1) m
2) n
3) C\!\(\*
StyleBox[\"L\",\nFontSize->8,\nFontWeight->\"Bold\"]\)=C\!\(\*
StyleBox[\"N\",\nFontSize->8,\nFontWeight->\"Bold\"]\)  
4) z(u)/l is the dimensionless conformal mapping in the form of a pure function. Usage: z[u_]=paramlim[\[Sigma]][[4]][u]."


GraphRJ::usage="\!\(\*
StyleBox[\"GraphRJ: The\",\nFontSize->16,\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",\nFontSize->16,\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"shapes\",\nFontSize->16,\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",\nFontSize->16,\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"of\",\nFontSize->16,\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",\nFontSize->16,\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"the\",\nFontSize->16,\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",\nFontSize->16,\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"cavity\",\nFontSize->16,\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",\nFontSize->16,\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"and\",\nFontSize->16,\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",\nFontSize->16,\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"the\",\nFontSize->16,\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",\nFontSize->16,\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"plate\",\nFontSize->16,\nFontWeight->\"Bold\"]\)
\!\(\*
StyleBox[\"Usage\",\nFontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\":\",\nFontColor->RGBColor[1, 0, 0]]\) GraphRJ[\[Alpha],\[Beta],\[Sigma],eps,DS,IS], where 
eps is a small parameter that defines the length of the reentrant jet. Usualy, eps=10^(-10)-10^(16). 
The less is eps the greater is the length.     
DS is the radius of the disk showing the location of the stagnation points. DS is given as a fraction of the cavity length Lc
IS is the image size of the graph.
\!\(\*
StyleBox[\"Output\",\nFontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\":\",\nFontColor->RGBColor[1, 0, 0]]\) The graph of the cavity shape and plate together with the bounding rectangle.
 The disks show the location of the stagnation points.
 The black disks are odinary stagnation points, the blue disk is a complementary stagnation points that appears if \[Alpha]<\[Alpha]crit." 



PrintMy::usage="\!\(\*
StyleBox[\"PrintMy\",\nFontSize->16,\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontSize->16,\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"a\",\nFontSize->16,\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontSize->16,\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"b\",\nFontSize->16,\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontSize->16,\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"c\",\nFontSize->16,\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"...\",\nFontSize->16,\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontSize->16,\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"{\",\nFontSize->16,\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"options\",\nFontSize->16,\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"}]\",\nFontSize->16,\nFontWeight->\"Bold\"]\)
A small routine that works as Print[a,b,c...] with an optional last argument that is a list of options
that are the same as for the routine Style[Text,options]."  


(* ::Input::Initialization:: *)
Begin["`Private`"]


(* ::Input::Initialization:: *)
fnum[\[Alpha]dim_,\[Beta]dim_, \[Sigma]dim_]:=Module[{WP,\[Alpha],\[Beta],\[Sigma],crit,a,b,c,d,k, P1,T,\[CapitalLambda], A,A1,B1, eqa1,eqa2,pol,ruld,rulc,rulap, rulapr, check1,check2,check3, lis,start,rulab,rulab1,rulk,rulmain,ii,err,ik},
Off[General::precw];
WP=56;
\[Alpha]=SetPrecision[Rationalize[\[Alpha]dim,10^(-2 WP)],2WP];
\[Beta]=SetPrecision[Rationalize[\[Beta]dim, 10^(- 2WP)],2WP];
\[Sigma]=SetPrecision[Rationalize[\[Sigma]dim,10^(- 2WP)],2WP];

crit=10^(-14);
(* Wonder!!!!*)
T=Tan[\[Alpha]/2];
P1=Cot[\[Beta]/2];
\[CapitalLambda]=1/Sqrt[1+\[Sigma]];
A=T/(1-\[CapitalLambda]);
A1=Sqrt[(A(2 A+Sqrt[1+4 A^2]))/(1+4 A^2)];
B1=Sqrt[(A (-2 A+Sqrt[1+4 A^2]))/(1+4 A^2)];
eqa1=-2 (b+b^3)^2 T (1+b (P1-T)+P1 T) \[CapitalLambda]-2 a^6 T (1-3 b P1+3 b T+P1 T) \[CapitalLambda]+2 a^4 T (2-4 b (P1-T)+5 b^3 (P1-T)+2 P1 T+5 b^2 (1+P1 T)) \[CapitalLambda]-2 a^2 T (1-10 b^3 (P1-T)+P1 T+b (-P1+T)+b^5 (-P1+T)+4 b^2 (1+P1 T)+11 b^4 (1+P1 T)) \[CapitalLambda]+a^7 (P1-T) \[CapitalLambda] (-1+\[CapitalLambda]+T^2 (1+\[CapitalLambda]))+a b^2 (1+b^2) (2 b (1+P1 T) (-1+T^2 (-1+\[CapitalLambda])-\[CapitalLambda])+(P1-T) (1-\[CapitalLambda]+T^2 (1+\[CapitalLambda]))+3 b^2 (P1-T) (1-\[CapitalLambda]+T^2 (1+\[CapitalLambda])))-a^5 (-2 b (1+P1 T) (-1+T^2 (-1+\[CapitalLambda])-\[CapitalLambda])+2 (P1-T) \[CapitalLambda] (-1+\[CapitalLambda]+T^2 (1+\[CapitalLambda]))+b^2 (P1-T) (1-3 \[CapitalLambda]+2 \[CapitalLambda]^2+T^2 (1+3 \[CapitalLambda]+2 \[CapitalLambda]^2)))+a^3 (-2 b (1+P1 T) (-1+T^2 (-1+\[CapitalLambda])-\[CapitalLambda])+(P1-T) \[CapitalLambda] (-1+\[CapitalLambda]+T^2 (1+\[CapitalLambda]))-4 b^3 (1+P1 T) (-1+\[CapitalLambda]+2 \[CapitalLambda]^2+T^2 (-1-\[CapitalLambda]+2 \[CapitalLambda]^2))+2 b^2 (P1-T) (-2-\[CapitalLambda]+3 \[CapitalLambda]^2+T^2 (-2+\[CapitalLambda]+3 \[CapitalLambda]^2))-b^4 (P1-T) (-2-\[CapitalLambda]+3 \[CapitalLambda]^2+T^2 (-2+\[CapitalLambda]+3 \[CapitalLambda]^2)));
eqa2=-a^2 (-1+a^2) b (2 (P1-T) (1+T^2)+(P1-3 a^2 P1-T+(-1+a (-4+3 a)) P1 T^2+T^3+a T (-4-3 a (-1+T^2))) \[CapitalLambda]+3 (-1+a^2) (P1-T) (1+T^2) \[CapitalLambda]^2)+b^3 ((-1+4 a^2+3 a^4) (P1-T) (1+T^2)+P1 (1-2 a^2-a^4+(-1+a (4+a (2+(-24+a) a))) T^2) \[CapitalLambda]+T (-1+T^2+a (4+a (2-24 a+a^2-(2+a^2) T^2))) \[CapitalLambda]-2 a^2 (1+a^2) (P1-T) (1+T^2) \[CapitalLambda]^2)-b^7 (P1-T) (1-\[CapitalLambda]+T^2 (1+\[CapitalLambda]))+a^2 (-1+a^2)^2 \[CapitalLambda] (-1-\[CapitalLambda]-T^2 (-1+2 a+\[CapitalLambda])-P1 T (1-2 a+T^2 (-1+\[CapitalLambda])+\[CapitalLambda]))+b^6 (1+\[CapitalLambda]+T (P1+T+P1 T^2-(T-6 a T+P1 (-1+6 a+T^2)) \[CapitalLambda]))+b^4 (16 a T (-P1+T) \[CapitalLambda]+10 a^3 T (-P1+T) \[CapitalLambda]+2 (1+P1 T) (1-T^2 (-1+\[CapitalLambda])+\[CapitalLambda])+a^2 (1+P1 T) (-2+\[CapitalLambda]+3 \[CapitalLambda]^2+T^2 (-1+\[CapitalLambda]) (2+3 \[CapitalLambda])))+b^2 (-(1+P1 T) (-1+T^2 (-1+\[CapitalLambda])-\[CapitalLambda])+12 a^3 (P1-T) T \[CapitalLambda]+10 a T (-P1+T) \[CapitalLambda]+2 a^5 T (-P1+T) \[CapitalLambda]+2 a^2 (1+P1 T) (1+T^2) (-1+\[CapitalLambda]^2)-a^4 (1+P1 T) (-5+\[CapitalLambda]+6 \[CapitalLambda]^2+T^2 (-1+\[CapitalLambda]) (5+6 \[CapitalLambda])))+b^5 (-T (-2+2 \[CapitalLambda]-4 a \[CapitalLambda]-2 T^2 (1+\[CapitalLambda])+a^2 (2-3 \[CapitalLambda]+\[CapitalLambda]^2+T^2 (1+\[CapitalLambda]) (2+\[CapitalLambda])))+P1 (-2+2 \[CapitalLambda]+4 a T^2 \[CapitalLambda]-2 T^2 (1+\[CapitalLambda])+a^2 (2-3 \[CapitalLambda]+\[CapitalLambda]^2+T^2 (1+\[CapitalLambda]) (2+\[CapitalLambda]))));
pol=-4 a^4 b T (1-k P1+(k+P1) T) \[CapitalLambda]-4 b (1+b^2) (b-k) (b+k) T (1-k P1+(k+P1) T) \[CapitalLambda]-4 a^2 b T (1+3 k (k+P1)+k^3 (P1-T)-3 k T+P1 T+3 k^2 P1 T+2 b^2 (1-k P1+(k+P1) T)) \[CapitalLambda]+a^5 (-1+k P1-(k+P1) T) (1+T^2) (-1+\[CapitalLambda]^2)+a^3 (2 b^2 (-1+k P1-(k+P1) T) (1+T^2) (-1+\[CapitalLambda]^2)+(-1+k^2) (-1+k P1-(k+P1) T) (1+T^2) (-1+\[CapitalLambda]^2)+2 b (1+k^2) (P1-T) ((-1+\[CapitalLambda])^2+T^2 (1+\[CapitalLambda])^2))+a (b^4 (-1+k P1-(k+P1) T) (1+T^2) (-1+\[CapitalLambda]^2)-k^2 (-1+k P1-(k+P1) T) (1+T^2) (-1+\[CapitalLambda]^2)+b^2 (1+T^2) (1+3 k (P1-T)+k^3 (P1-T)+P1 T+3 k^2 (1+P1 T)) (-1+\[CapitalLambda]^2)+2 b k (1+k^2) (1+P1 T) (T^2 (-1+\[CapitalLambda])^2+(1+\[CapitalLambda])^2)+2 b^3 (1+k^2) (P1-T) ((-1+\[CapitalLambda])^2+T^2 (1+\[CapitalLambda])^2));
ruld={d->-(((-1+k P1-(k+P1) T) (a^3 (-1+\[CapitalLambda])-(1+b^2) T (b-k+(b+k) \[CapitalLambda])+a^2 T (k (-1+\[CapitalLambda])+3 b (1+\[CapitalLambda]))-a (-1+3 b^2 (-1+\[CapitalLambda])+\[CapitalLambda]+2 b k (1+\[CapitalLambda]))))/(2 (-a^2 T (1-k P1+(k+P1) T) (-1+\[CapitalLambda])+T (-k (k+P1-T+k P1 T) (-1+\[CapitalLambda])+b^2 (1-k P1+(k+P1) T) (-1+\[CapitalLambda])-b (1+k^2) (P1-T) (1+\[CapitalLambda]))+a (-(1+k^2) (P1-T) (-1+\[CapitalLambda])-2 b (-1+k P1-(k+P1) T) (1+\[CapitalLambda])))))};

rulc={c->Sqrt[1-d^2+(2 d (k+P1-T+k P1 T))/(-1+k P1-(k+P1) T)]};
rulap[1]={a->1+(((1+T^2) (-3-4 P1 T+T^2))/(32 T^2)-((1+T^2) (13+24 P1 T-7 T^2+P1^2 (-3+T^2)) (1-\[CapitalLambda]))/(128 T^2)) (1-\[CapitalLambda])^2,b->(1/4 (1/T+T)-((-3+P1^2) (1+T^2) (1-\[CapitalLambda]))/(32 T)) (1-\[CapitalLambda])};

rulap[2]={a->(Sqrt[T] \[CapitalLambda]^(1/4) Sqrt[1+\[CapitalLambda]])/(Sqrt[1-\[CapitalLambda]] Sqrt[1+P1^2 (-1+\[CapitalLambda])+\[CapitalLambda]])+(T (P1-3 P1 \[CapitalLambda]))/(2 (1+P1^2 (-1+\[CapitalLambda])+\[CapitalLambda])),b->(Sqrt[T] \[CapitalLambda]^(3/4) Sqrt[1+\[CapitalLambda]])/(Sqrt[1-\[CapitalLambda]] Sqrt[1+P1^2 (-1+\[CapitalLambda])+\[CapitalLambda]])-(P1 T Sqrt[\[CapitalLambda]] (1+5 \[CapitalLambda]))/(2 (1+P1^2 (-1+\[CapitalLambda])+\[CapitalLambda]))};

rulap[3]={a->A1+((-2 A A1^5 (5+4 A1) P1+8 A^3 A1 (1+A1+4 A1^2+4 A1^3-10 A1^4-8 A1^5) P1-32 A^5 A1 (-1-4 A1^2-4 A1^3+5 A1^4+4 A1^5) P1+A1^6 (3+2 P1^2)+4 A^4 (-1+A1^2) (1+2 A1^2+20 A1^4+(-1-4 A1^2+8 A1^4) P1^2)+A^2 A1^2 (-4-14 A1^2+32 A1^4+(-1-12 A1^2+16 A1^4) P1^2)) (1-\[CapitalLambda]))/(4 (2 A1^5+8 A^4 A1^3 (-3+4 A1^2)+A^2 A1 (-1-6 A1^2+16 A1^4))),b->B1+((-8 A B1^4 (1+B1^2) P1-128 A^5 (B1+B1^3)^2 P1-8 A^3 (-1+3 B1^2+12 B1^4+8 B1^6) P1+2 B1^4 (1+B1^2) (2+P1^2)+4 A^4 B1^2 (31+46 B1^2+24 B1^4+18 B1 P1+(3+20 B1^2+8 B1^4) P1^2)+A^2 (-7+23 B1^2+58 B1^4+40 B1^6+6 B1 (-1+3 B1^2) P1+(-1-B1^2+28 B1^4+16 B1^6) P1^2)) (1-\[CapitalLambda]))/(4 B1 (B1^2+2 B1^4+8 A^4 (1+5 B1^2+4 B1^4)+A^2 (1+14 B1^2+16 B1^4)))};


check1=-(((1-I T) (P1-I))/((1+I T) (P1+I)))+((1-c-I d) (1+c-I d) (1-I k))/((1-c+I d) (1+c+I d) (1+I k));

check2=((a+I b-c-I d) (a+I b+c-I d) (a+I b-I k))/((a+I b-c+I d) (a+I b+c+I d) (a+I b+I k))-((1-I T) \[CapitalLambda])/(1+I T);

check3=(I (a+I b))/(2 a b)-(a+I b)/((a+I b)^2-1)+(2 (a+I b+I d))/((a+I b+I d)^2-c^2)+1/(a+I b+I k);

lis={{If[\[Alpha]<Pi/4,Sqrt[eqa1^2+eqa2^2]/.rulap[1],0],1}, {Sqrt[eqa1^2+eqa2^2]/.rulap[2],2}, {Sqrt[eqa1^2+eqa2^2]/.rulap[3],3}};
lis=Sort[lis];

    Do[rulapr=rulap[lis[[ii,2]]];
start={{a,(a/.rulapr)},{b,(b/.rulapr)}};
rulab=FindRoot[Evaluate[{eqa1==0,eqa2==0}],start, WorkingPrecision-> WP, MaxIterations->200];
If[(a/.rulab)>crit &&(b/.rulab)>crit ,ik=ii; Break[]] ,{ii,1,3}];On[General::precw];
rulab1={a->( Rationalize[a/.rulab,10^(-WP)]),b-> Rationalize[b/.rulab,10^(-WP)]};
rulk=NSolve[Evaluate[{pol==0,k>0}/.rulab1],k, WorkingPrecision->WP] [[1,1]];
rulmain=Flatten[Join[rulab,{rulk}]];
rulmain=Flatten[Join[rulmain,{d-> (d/.ruld/.rulmain)}]];
rulmain=Sort[Flatten[Join[rulmain,{c-> (c/.rulc/.rulmain)}]]];
err=Max[Abs[{check1/.rulmain,check2/.rulmain,check3/.rulmain}]];
Flatten[Append[{a,b,c,d,k}/.rulmain,{err,ik}]]
];



(* ::Input::Initialization:: *)
param[\[Alpha]dima_,\[Beta]dima_,Qdima_]:=Module[{\[Alpha],\[Beta], Q,rul,tt,m, mx, my,a,b,c,d,k,\[Sigma],q,\[Gamma],J,\[Delta],\[Gamma]1,Cn, m1,T,z,z1,Lc,Hc, P1,P2,Q1, Q2,\[Xi],ls1,ls2,  ui,uic,p1,p2,p3,p4, WP,eps,xsq,ysq,h},
tt=fnum[\[Alpha]dima,\[Beta]dima,Qdima];
rul={a-> tt[[1]],b-> tt[[2]],c-> tt[[3]],d-> tt[[4]], k-> tt[[5]]};
WP=56;
 \[Alpha]=SetPrecision[Rationalize[\[Alpha]dima,10^(- WP)], WP]; 
\[Beta]=SetPrecision[Rationalize[\[Beta]dima,10^(- WP)], WP];
Q=SetPrecision[Rationalize[Qdima,10^(- WP)], WP];
\[Sigma]=1/Sqrt[1+Q];
ui=a+I b;
uic=a - I b; 
m=((a^2+2 I a b-b^2-(c-I d)^2) (a^2+2 I a b-b^2-(c+I d)^2) (a^2+2 I a b-b^2+k^2))/(64 a^2 (a+I b) b^2 (-1+a^2+2 I a b-b^2))/.rul;mx=Re[m];my=Im[m];q=((c^4+2 c^2 (-1+d^2)+(1+d^2)^2) (1+k^2) \[Pi])/(2 (a^4+2 a^2 (-1+b^2)+(1+b^2)^2)^2)/.rul; \[Gamma]=q/\[Sigma](Cot[\[Alpha]](Cos[\[Beta]]-\[Sigma])-Sin[\[Beta]]); J=-\[Gamma] \[Sigma] Cos[\[Alpha]]+q \[Sigma] Sin[\[Alpha]]+(-2 (a mx+b my) (1+\[Sigma]^2) Cos[\[Alpha]]+2 (b mx-a my) (-1+\[Sigma]^2) Sin[\[Alpha]])/((a^2+b^2) \[Sigma])+(\[Sigma] (2 ArcTan[b/a] (\[Gamma] Cos[\[Alpha]]-q Sin[\[Alpha]])-Log[a^2+b^2] (q Cos[\[Alpha]]+\[Gamma] Sin[\[Alpha]])))/\[Pi]-q Sin[\[Alpha]+\[Beta]]/.rul;
p1=(E^(-I \[Alpha]) (mx-I my))/((1+a-I b) \[Sigma])-(E^(I \[Alpha]) (mx+I my))/((1-a-I b) \[Sigma])-(E^(I \[Alpha]) (mx-I my) \[Sigma])/(1-a+I b)+(E^(-I \[Alpha]) (mx+I my) \[Sigma])/(1+a+I b)+(E^(I \[Alpha]) (q-I \[Gamma]) \[Sigma] Log[1/2 (1-a+I b)])/\[Pi]+(E^(-I \[Alpha]) (q+I \[Gamma]) \[Sigma] Log[1/2 (1+a+I b)])/\[Pi]/.rul;
p2=(E^(-I \[Alpha]) (mx-I my))/(2 a \[Sigma])+(I E^(I \[Alpha]) (mx-I my) \[Sigma])/(2 b)+(E^(-I \[Alpha]) (mx+I my) \[Sigma])/(2 a+2 I b)-(E^(I (\[Alpha]+\[Beta])) q Log[(-1+a+I b)/(1+a+I b)])/\[Pi]+(E^(-I \[Alpha]) (q+I \[Gamma]) \[Sigma] Log[(2 a+2 I b)/(1+a+I b)])/\[Pi]+(E^(I \[Alpha]) (q-I \[Gamma]) \[Sigma] Log[(2 I b)/(1+a+I b)])/\[Pi]/.rul;
p3=-((2 (c-I d))/((a+I b)^2-(c-I d)^2))+(2 (c+I d))/((a+I b)^2-(c+I d)^2)+(2 I k)/((a+I b)^2+k^2)/.rul;
p4=(4 (a+I b) (c-I d))/((a+I b)^2-(c-I d)^2)^2-(4 (a+I b) (c+I d))/((a+I b)^2-(c+I d)^2)^2-(4 I (a+I b) k)/((a+I b)^2+k^2)^2/.rul;

h=(q/2-Im[E^(-(\[Alpha]+\[Beta])I)p1])/J;
m1=2/J^2(Im[Pi m^2(p3^2+p4)-2m Pi p2 p3  \[Sigma] E^(-I \[Alpha])+q p1 E^(-I(\[Alpha]+\[Beta]))]+\[Gamma] q/(2 Pi)-q^2/2)*(1+Q);

z[u_]=(-E^(I \[Alpha])/\[Sigma](mx+I my)/(u-ui)+E^(-I \[Alpha])/\[Sigma](mx-I my)/(u+uic)-
E^(I \[Alpha])\[Sigma] (mx-I my)/(u-uic)+ E^(-I \[Alpha])\[Sigma] (mx+I my)/(u+ui)+
\[Sigma] E^(I \[Alpha])(q-I \[Gamma])/Pi Log[(u-uic)/(u+1)]+\[Sigma] E^(-I \[Alpha])(q+I \[Gamma])/Pi Log[(u+ui)/(u+1)]-
E^((\[Alpha]+\[Beta])I)q/Pi Log[(u-1)/(u+1)])*E^(-I \[Alpha])/J/.rul;
z1[u_]=E^(-2 I \[Alpha]) ((E^(2 I \[Alpha]) (mx+I my) u)/((-1+u ui) \[Sigma])+((mx+I my) u \[Sigma])/(1+u ui)+(E^(2 I \[Alpha]) (mx-I my) u \[Sigma])/(-1+u uic)+((mx-I my) u)/(\[Sigma]+u uic \[Sigma])-(E^(I (2 \[Alpha]+\[Beta])) q Log[-1+2/(1+u)])/\[Pi]+((q+I \[Gamma]) \[Sigma] Log[(1+u ui)/(1+u)])/\[Pi]+(E^(2 I \[Alpha]) (q-I \[Gamma]) \[Sigma] Log[(1-u uic)/(1+u)])/\[Pi])/J/.rul;
P1=-(c^2+d^2) k (-1+T)-(c^2+d (d+2 k)) (1+T) \[Xi]+(2 d+k) (-1+T) \[Xi]^2+(1+T) \[Xi]^3;
P2=-(c^2+d^2) k (1+T)+(c^2+d (d+2 k)) (-1+T) \[Xi]+(2 d+k) (1+T) \[Xi]^2+(1-T) \[Xi]^3;
Q1=-(c^2+d^2) k T+(-c^2-d (d+2 k)) \[Xi]+(2 d+k) T \[Xi]^2+\[Xi]^3;
Q2=(c^2+d^2) k-(c^2+d (d+2 k)) T \[Xi]+(-2 d-k) \[Xi]^2+T \[Xi]^3;
ls1=Sort[Join[\[Xi]/.NSolve[{Evaluate[P1/.T->Tan[\[Alpha]/2]/.rul]==0,\[Xi]>= 0},\[Xi],Reals, WorkingPrecision-> WP],  
\[Xi]/.NSolve[{Evaluate[P2/.T->Tan[\[Alpha]/2]/.rul]==0,\[Xi]>= 0},\[Xi],Reals, WorkingPrecision-> WP ]] , Less]; 
ls2=Sort[Join[\[Xi]/. NSolve[{Evaluate[Q1/.T->Tan[\[Alpha]/2]/.rul]==0,\[Xi]>= 0},\[Xi],Reals, WorkingPrecision-> WP ],  
\[Xi]/.NSolve[{Evaluate[Q2/.T->Tan[\[Alpha]/2]/.rul]==0,\[Xi]>= 0},\[Xi],Reals,  WorkingPrecision-> WP]],Less];
eps=10^(-12);
ls1=DeleteCases[ls1,x_/;Abs[x-1]<=eps];
ls1=DeleteCases[ls1,\[Xi]];
ls1=Re[z[ls1]];
xsq=Min[ls1];
ls2=DeleteCases[ls2,x_/;Abs[x-1]<=eps];
ls2=DeleteCases[ls2,\[Xi]];
ls2=Im[z[ls2]];
ysq=Max[ls2];
Lc=Max[ls1]-Min[ls1];
If[Length[ls2]==1,Hc=Max[ls2],Hc=Max[ls2]-Min[ls2]];
\[Delta]=q/J; \[Gamma]1=\[Gamma]/J/\[Sigma]; Cn=2/Sin[\[Alpha]]/J(1+Q)q(\[Sigma]-Cos[\[Beta]]);(*{\[Delta],\[Gamma]1,Cn,m1,Lc,Hc,J,Evaluate[z[#]]&,Evaluate[z1[#]]&,z[I k/.rul],z[c+ I d/.rul], z[-c+ I d/.rul], xsq,ysq, h, tt[[6]]};*){{tt[[1]],tt[[2]],tt[[3]],tt[[4]],tt[[5]],J,tt[[6]]},{Cn,m1,\[Gamma]1},{\[Delta],Lc,Hc,xsq,ysq,h}, {Evaluate[z[#]]&,Evaluate[z1[#]]&}}];


(* ::Input::Initialization:: *)
paramlim[\[Sigma]dim_]:=Module[{WP,M, \[Gamma],U,\[CapitalLambda],J,m,n,\[Zeta],z,\[Gamma]1,Cn },WP=56;
\[Sigma]=SetPrecision[Rationalize[\[Sigma]dim,10^(- 2WP)],WP];
 \[CapitalLambda]=1/Sqrt[1+\[Sigma]];U=Sqrt[1+Sqrt[1+\[Sigma]]];
m=Sqrt[-(((-2+U) (1+U))/((-1+U) (2+U)))];n=Sqrt[-1+U]/Sqrt[1+U];M=(1+U)^3/(2 U (-2+U+U^2)^2); \[Gamma]=-((\[Pi] (1+U)^(7/2) (-2+U^2))/(2 (-1+U)^(5/2) (2+U)^2));J=  (4 M)/((1+n^2) \[CapitalLambda])+(4 M \[CapitalLambda])/(1+n^2)-(4 \[Gamma] \[CapitalLambda] ArcTan[n])/\[Pi]; \[Zeta][t_]=-((2 M t)/((n^2+t^2) \[CapitalLambda]))-(2 M t \[CapitalLambda])/(1+n^2 t^2)+(2 \[Gamma] \[CapitalLambda] ArcTan[n t])/\[Pi]; Cn=- 2/J Sqrt[1+\[Sigma]] \[Gamma];
z[t_]=\[Zeta][t]/J-1/2; {m,n,Cn,Evaluate[z[#]]&} ];


GraphRJ[\[Alpha]_,\[Beta]_,\[Sigma]_,eps_, DS_,IS_]:=Block[{tr,z,z1,grplate,grup,grlow,xsq,ysq,Lc,Hc,point1,point2,point3,disk1,disk2,disk3,rect,grlist,zz1,zz2,zz3},
tr=param[\[Alpha],\[Beta],\[Sigma]];
z[\[Xi]_]=tr[[4,1]][\[Xi]];
z1[\[Xi]_]=tr[[4,2]][\[Xi]];
grplate=Graphics[{Thick,Red,Line[{{0,0},{-Cos[\[Alpha]],Sin[\[Alpha]]}}]}];   
grup=ParametricPlot[zz=z[\[Xi]^3]; {Re[zz],Im[zz]},{\[Xi],0,Sqrt[1-eps]}, PlotRange->All, PlotPoints-> 400];
grlow=ParametricPlot[zz=z1[\[Xi]^3]; {Re[zz],Im[zz]},{\[Xi],0,Sqrt[1-eps]},PlotRange->All,  PlotPoints->400];
xsq=tr[[3,4]];
ysq=tr[[3,5]];
Lc=tr[[3,2]];
Hc=tr[[3,3]];
zz1=I tr[[1,5]];
zz2=tr[[1,3]]+I *tr[[1,4]];
zz3=-tr[[1,3]]+I *tr[[1,4]];
rect=Graphics[Line[{{xsq,ysq}, {xsq+Lc,ysq}, {xsq+Lc, ysq-Hc},{xsq, ysq-Hc} , {xsq,ysq}}]];
grlist={grplate,grup,grlow, rect};
If[Im[zz1]>= 0&& Re[zz1]>= 0,point1=z[zz1];
disk1=Graphics[{Black,Disk[{Re[point1],Im[point1]},DS*Lc]}]; grlist=Append[grlist,disk1]]; 
If[Im[zz2]>= 0&& Re[zz2]>= 0,point2=z[zz2];
disk2=Graphics[{Black,Disk[{Re[point2],Im[point2]},DS*Lc]}]; grlist=Append[grlist,disk2]]; 
If[Im[zz3]>= 0&& Re[zz3]>= 0,point3=z[zz3];
disk3=Graphics[{Blue,Disk[{Re[point3],Im[point3]},DS*Lc]}]; grlist=Append[grlist,disk3]]; 
Show[grlist, PlotRange->All, Axes-> True, ImageSize-> IS ]];


PrintMy[xdim__,ydim_List:{}]:= Block[{nx,lis,sec,xdvmstrange,arg},xdvmstrange={xdim};sec=ydim/.List-> Sequence;
nx=Length[xdvmstrange];
lis={};
Do[lis=Append[lis,Style[xdvmstrange[[i]],sec]],{i,1,nx}];
Print[lis/. List[arg__]-> Sequence[arg]]];


(* ::Input::Initialization:: *)
End[]


(* ::Input::Initialization:: *)
EndPackage[]
